Kubedantic
======================================================

.. image:: https://img.shields.io/pypi/v/kubedantic.svg
   :target: https://pypi.org/project/kubedantic

.. image:: https://img.shields.io/pypi/pyversions/kubedantic.svg

.. image:: https://github.com/coherent-oss/kubedantic/actions/workflows/main.yml/badge.svg
   :target: https://github.com/coherent-oss/kubedantic/actions?query=workflow%3A%22tests%22
   :alt: tests

.. image:: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json
    :target: https://github.com/astral-sh/ruff
    :alt: Ruff

.. .. image:: https://readthedocs.org/projects/kubedantic/badge/?version=latest
..    :target: https://kubedantic.readthedocs.io/en/latest/?badge=latest

.. image:: https://img.shields.io/badge/skeleton-2024-informational
   :target: https://blog.jaraco.com/skeleton

Kubedantic - Pydantic models for Kubernetes

Overview
--------

Kubedantic is a Python library that provides Pydantic models for Kubernetes resources.

Models are generated using the `Kubernetes OpenAPI specification <https://github.com/kubernetes/kubernetes/tree/master/api/openapi-spec/v3>`_ and `datamodel-code-generator <https://github.com/koxudaxi/datamodel-code-generator>`_.
